==> haskell-network-ip-0.3.0.3-128-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-ip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 network-ip
version:              0.3.0.3
visibility:           public
id:                   network-ip-0.3.0.3-AUup8mPjmvD5oPc30Fexfd
key:                  network-ip-0.3.0.3-AUup8mPjmvD5oPc30Fexfd
license:              BSD-3-Clause
copyright:            2011-2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/network-ip
synopsis:             Internet Protocol data structures
description:          This package provides Internet Protocol data structures
category:             Network
abi:                  1024197633620fb3f846d6d007ee0eda
exposed:              True
exposed-modules:      Network.IP.Addr
import-dirs:          /usr/lib/ghc-8.10.4/site-local/network-ip-0.3.0.3
library-dirs:         /usr/lib/ghc-8.10.4/site-local/network-ip-0.3.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/network-ip-0.3.0.3
hs-libraries:         HSnetwork-ip-0.3.0.3-AUup8mPjmvD5oPc30Fexfd
depends:
    base-4.14.1.0 data-default-class-0.1.2.0-56BXPST0gStFZdhRwxhsn8
    data-dword-0.3.2-FfnSr0OXsMTCaCIJcVWyNX
    data-endian-0.1.1-5ELABUSHRCN9Wd3DzqzD6m
    data-serializer-0.3.4.1-DFtBGCgoOkIKlha1V9uf8x
    data-textual-0.3.0.3-5VlbVxsM9mICzXDICYGzXB
    hashable-1.3.1.0-4EsGp1K7uOu2cACWuCidz3
    parsers-0.12.10-CwOfIgigS5h1OinokBgFQl
    text-printer-0.5.0.1-Bp2LXSrIup5LJ1hkatTNe3
    type-hint-0.1-LLatgpWY2Uk4zIlrhr3wLH

haddock-interfaces:   /usr/share/doc/haskell-network-ip/html/network-ip.haddock
haddock-html:         /usr/share/doc/haskell-network-ip/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-ip-0.3.0.3-129-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-ip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 network-ip
version:              0.3.0.3
visibility:           public
id:                   network-ip-0.3.0.3-EUbw83erSnvETrWD00r46s
key:                  network-ip-0.3.0.3-EUbw83erSnvETrWD00r46s
license:              BSD-3-Clause
copyright:            2011-2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/network-ip
synopsis:             Internet Protocol data structures
description:          This package provides Internet Protocol data structures
category:             Network
abi:                  4e8602e1c41aea4cb35fe2cfb0166ca2
exposed:              True
exposed-modules:      Network.IP.Addr
import-dirs:          /usr/lib/ghc-8.10.4/site-local/network-ip-0.3.0.3
library-dirs:         /usr/lib/ghc-8.10.4/site-local/network-ip-0.3.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/network-ip-0.3.0.3
hs-libraries:         HSnetwork-ip-0.3.0.3-EUbw83erSnvETrWD00r46s
depends:
    base-4.14.1.0 data-default-class-0.1.2.0-56BXPST0gStFZdhRwxhsn8
    data-dword-0.3.2-LMpSecO8fU9HSlQa07HoWj
    data-endian-0.1.1-5ELABUSHRCN9Wd3DzqzD6m
    data-serializer-0.3.4.1-BnOSzxBLbZ33Ce3M3cmNZ1
    data-textual-0.3.0.3-AXIZkSB5K4O8cauDtVQ0f9
    hashable-1.3.1.0-1TzQw0rlraYH9EvMt0jxBh
    parsers-0.12.10-59FBErwDiGdCvpJKX8tU5G
    text-printer-0.5.0.1-F17Xb8nh9MmDUE9PlN8fVI
    type-hint-0.1-LLatgpWY2Uk4zIlrhr3wLH

haddock-interfaces:   /usr/share/doc/haskell-network-ip/html/network-ip.haddock
haddock-html:         /usr/share/doc/haskell-network-ip/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
